@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.0.0';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.1.0';
 #pod =encoding UTF-8
 #pod
 #pod =head1 SYNOPSIS
@@ -119,6 +119,8 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.0.0';
 #pod     [PodSyntaxTests]
 #pod     [Test::Pod::No404s]
 #pod     [Test::Pod::LinkCheck]
+#pod     [Test::EOL]
+#pod     [Test::NoTabs]
 #pod
 #pod     #
 #pod     # Copy files back into project dir
@@ -132,8 +134,13 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.0.0';
 #pod     [TestRelease]
 #pod
 #pod     [Git::Check]
+#pod     allow_dirty => cpanfile
+#pod
 #pod     [Git::Commit]
+#pod     allow_dirty => cpanfile
+#pod     allow_dirty => Changes
 #pod     commit_msg = Release %v%n%n%c
+#pod
 #pod     [Git::Tag]
 #pod     tag_format  = %v
 #pod     ;# make a lightweight tag
@@ -318,6 +325,8 @@ sub configure {
         'PodSyntaxTests',
         'Test::Pod::No404s',
         'Test::Pod::LinkCheck',
+        'Test::EOL',
+        'Test::NoTabs',
 
         #
         # Replacement of files in project dir
@@ -336,6 +345,7 @@ sub configure {
         }],
         ['Git::Commit' => {
             'allow_dirty' => 'cpanfile',  # add cpanfile because we copy it back from release
+            'allow_dirty' => 'Changes',   # add cpanfile because its modified by [NextRelease]
             'commit_msg' => 'Release %v%n%n%c',
         }],
         ['Git::Tag' => {
@@ -354,7 +364,7 @@ __PACKAGE__->meta->make_immutable;
 {
     package Dist::Zilla::Plugin::ShareDir::ProjectDistDir;
     # ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.0.0';
+$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.1.0';
 use Moose;
     use namespace::autoclean;
 
@@ -402,7 +412,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 3.0.0
+version 3.1.0
 
 =head1 SYNOPSIS
 
@@ -525,6 +535,8 @@ Currently this plugin bundle is equivalent to:
     [PodSyntaxTests]
     [Test::Pod::No404s]
     [Test::Pod::LinkCheck]
+    [Test::EOL]
+    [Test::NoTabs]
 
     #
     # Copy files back into project dir
@@ -538,8 +550,13 @@ Currently this plugin bundle is equivalent to:
     [TestRelease]
 
     [Git::Check]
+    allow_dirty => cpanfile
+
     [Git::Commit]
+    allow_dirty => cpanfile
+    allow_dirty => Changes
     commit_msg = Release %v%n%n%c
+
     [Git::Tag]
     tag_format  = %v
     ;# make a lightweight tag
